@@ -1,5 +1,6 @@
 import hashlib
 import unittest
+from textwrap import dedent
 
 from eodatasets3 import verify
 
@@ -7,19 +8,19 @@ from tests import write_files
 
 
 class VerifyTests(unittest.TestCase):
-    def test_checksum(self):
+    def test_checksum(self):  # noqa: T003
         d = write_files({"test1.txt": "test"})
 
         test_file = d.joinpath("test1.txt")
 
         sha1_hash = verify.calculate_file_hash(test_file)
-        self.assertEqual(sha1_hash, "a94a8fe5ccb19ba61c4c0873d391e987982fbbd3")
+        assert sha1_hash == "a94a8fe5ccb19ba61c4c0873d391e987982fbbd3"
 
         md5_hash = verify.calculate_file_hash(test_file, hash_fn=hashlib.md5)
-        self.assertEqual(md5_hash, "098f6bcd4621d373cade4e832627b4f6")
+        assert md5_hash == "098f6bcd4621d373cade4e832627b4f6"
 
         crc32_checksum = verify.calculate_file_crc32(test_file)
-        self.assertEqual(crc32_checksum, "d87f7e0c")
+        assert crc32_checksum == "d87f7e0c"
 
     def test_package_checksum(self):
         d = write_files(
@@ -44,12 +45,15 @@ class VerifyTests(unittest.TestCase):
         # One (hash, file) per line separated by a tab.
         #  - File paths must be relative to the checksum file.
         #  - Output in filename alphabetical order.
-        self.assertEqual(
-            """109f4b3c50d7b0df729d299bc6f8e9ef9066971f\tpackage/test2.txt
-3ebfa301dc59196f18593c45e519287a23297589\tpackage/test3.txt
-a94a8fe5ccb19ba61c4c0873d391e987982fbbd3\ttest1.txt
-""",
-            doc,
+        assert (
+            dedent(
+                """\
+            109f4b3c50d7b0df729d299bc6f8e9ef9066971f\tpackage/test2.txt
+            3ebfa301dc59196f18593c45e519287a23297589\tpackage/test3.txt
+            a94a8fe5ccb19ba61c4c0873d391e987982fbbd3\ttest1.txt
+            """
+            )
+            == doc
         )
 
         # After dumping to a file, read()'ing from the file should give us identical values.
